@@ -18,11 +18,12 @@ from aiohttp import (
     ClientResponse,
     ClientSession,
     ClientTimeout,
+    ContentTypeError,
     TCPConnector,
 )
 
 if TYPE_CHECKING:
-    from pyroute2 import IPRoute  # type: ignore
+    from pr2modules.iproute import IPRoute  # type: ignore
 
 
 class UnifiService(Enum):
@@ -252,7 +253,9 @@ class ArpSearch:
         """Get neighbors from the arp table."""
         self.ip_route = None
         with suppress(Exception):
-            from pyroute2 import IPRoute  # pylint: disable=import-outside-toplevel
+            from pr2modules.iproute import (  # pylint: disable=import-outside-toplevel
+                IPRoute,
+            )
 
             self.ip_route = IPRoute()
         if self.ip_route:
@@ -430,6 +433,11 @@ class AIOUnifiScanner:
                     continue
                 try:
                     system = await system_response.json()
+                except ContentTypeError as ex:
+                    _LOGGER.debug(
+                        "System endpoint not available for %s: %s", source_ip, ex
+                    )
+                    continue
                 except (asyncio.TimeoutError, ClientError):
                     _LOGGER.exception("Failed to get system info for %s", source_ip)
                     continue
@@ -437,11 +445,12 @@ class AIOUnifiScanner:
                     continue
                 device = response_list[source_ip]
                 short_name = system.get("hardware", {}).get("shortname")
+                mac = system.get("mac")
                 response_list[source_ip] = replace(
                     device,
                     platform=device.platform or short_name,
                     hostname=device.hostname or system.get("name").replace(" ", "-"),
-                    hw_addr=device.hw_addr or _format_mac(system.get("mac")),
+                    hw_addr=device.hw_addr or (_format_mac(mac) if mac else None),
                     direct_connect_domain=system.get("directConnectDomain"),
                     is_sso_enabled=system.get("isSsoEnabled"),
                     is_single_user=system.get("isSingleUser"),
